# Generated by roxygen2: do not edit by hand

S3method(coef,xtfifevd)
S3method(confint,xtfifevd)
S3method(print,summary.xtfifevd)
S3method(print,xtfifevd)
S3method(summary,xtfifevd)
S3method(vcov,xtfifevd)
export(bw_ratio)
export(fef)
export(fef_iv)
export(fevd)
export(xtfifevd)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,fitted)
importFrom(stats,lm.fit)
importFrom(stats,na.omit)
importFrom(stats,pnorm)
importFrom(stats,printCoefmat)
importFrom(stats,qnorm)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(stats,vcov)
