% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{xtfifevd-methods}
\alias{xtfifevd-methods}
\title{Methods for xtfifevd objects}
\description{
Methods for xtfifevd objects
}
\keyword{internal}
