% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimation.R
\name{estimation-internal}
\alias{estimation-internal}
\title{Internal estimation functions}
\description{
Internal estimation functions
}
\keyword{internal}
